import argparse
import logging

from pysatl import Utils

from sha256bit import Sha256bit

if __name__ == '__main__':
    parser = argparse.ArgumentParser(description='sha256bit.cli')
    levels = ('DEBUG', 'INFO', 'WARNING', 'ERROR', 'CRITICAL')
    parser.add_argument('--log-level', default='WARNING', choices=levels)
    parser.add_argument('--bit-length', help='Bit length of message', default=None, type=int)
    parser.add_argument('message', nargs=1, help='Message to hash', type=str)
    args = parser.parse_args()
    logging.basicConfig(format='%(message)s', level=args.log_level)
    msg = Utils.ba(args.message[0])
    digest = Sha256bit(msg, bitlen=args.bit_length).digest()
    print(Utils.hexstr(digest))



# Configuration file for the Sphinx documentation builder.
#
# For the full list of built-in configuration values, see the documentation:
# https://www.sphinx-doc.org/en/master/usage/configuration.html

# -- Project information -----------------------------------------------------
# https://www.sphinx-doc.org/en/master/usage/configuration.html#project-information

project = 'sha256bit'
copyright = '2023, Sebastien Riou'
author = 'Sebastien Riou'

# -- General configuration ---------------------------------------------------
# https://www.sphinx-doc.org/en/master/usage/configuration.html#general-configuration

import sys, os

# add root of the repo to the search path for modules
p = os.path.abspath(os.path.join('..', '..'))
sys.path.append(p)

extensions = [
    'sphinx_rtd_theme',
    'sphinx.ext.autodoc',
    'sphinx.ext.doctest',
    'sphinx_autodoc_typehints',
    'sphinx.ext.napoleon',
]

templates_path = ['_templates']
exclude_patterns = []


# -- Options for HTML output -------------------------------------------------
# https://www.sphinx-doc.org/en/master/usage/configuration.html#options-for-html-output

html_theme = 'sphinx_rtd_theme'
html_static_path = ['_static']
